==> inkscape-textext_1.3.0.orig.tar.xz: inkscape-textext-1.3.0/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve the extension
title: ''
labels: ''
assignees: ''

---

**Description of the problem/ steps to reproduce**
A clear and concise description of what the bug is and what you expected to happen.

**Steps to reproduce the behavior (if not obvious from description)**:
1. ....
2. ....
3. ....

**Message(s) in error dialog (if this comes up)**
Please paste the error message(s) at the marked positions:

<details>
<summary>dialog output (if available):</summary>

```
<<< REPLACE THIS LINE WITH ACTUAL OUTPUT >>> 
```
</details>

<details>
<summary>output of stdout (if available):</summary>

```
<<< REPLACE THIS LINE WITH ACTUAL OUTPUT >>> 
```
</details>

<details>
<summary>output of stderr (if available):</summary>

```
<<< REPLACE THIS LINE WITH ACTUAL OUTPUT >>> 
```
</details>


**Logfile**
Please also *attach* the TexText log file (since TexText 0.9.x). You find it in `~/.config/inkscape/extensions/textext` on Linux/ MacOS or in `C:\Users\[Your user name]\AppData\Roaming\inkscape\extensions\textext` on Windows

**Screenshots**
If applicable and helpful, add screenshots to help explain your problem.

**System information**

- TexText version:
- Inkscape version:
- Operating system: [e.g. Windows 10, 1803, 32-bit]
- Windows only: LaTeX-distribution (MiKTeX, TeX-Live):
- Windows only: TexText installed via batch script or installer file:

**Additional information if you still use Inkscape 0.92.x / TexText 0.11**

- SVG-converter installed (pstoedit+ghostscript or pdf2svg):
- GUI framework installed (PyGTK, PyGTK+PyGTK-Sourceview, TkInter):

==> inkscape-textext_1.8.2.orig.tar.xz: inkscape-textext-1.8.2/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve the extension
title: ''
labels: ''
assignees: ''

---
**Before submitting a bug report make sure you have checked the
  [FAQ](https://textext.github.io/textext/usage/faq.html) and
  [Troubleshooting](https://textext.github.io/textext/usage/troubleshooting.html)
  sections in the documentation!**

**Description of the problem/ steps to reproduce**
A clear and concise description of what the bug is and what you expected to happen.

**Steps to reproduce the behavior (if not obvious from description)**:
1. ....
2. ....
3. ....

**Message(s) in error dialog (if this comes up)**
Please paste the error message(s) at the marked positions:

<details>
<summary>dialog output (if available):</summary>

```
<<< REPLACE THIS LINE WITH ACTUAL OUTPUT >>> 
```
</details>

<details>
<summary>output of stdout (if available):</summary>

```
<<< REPLACE THIS LINE WITH ACTUAL OUTPUT >>> 
```
</details>

<details>
<summary>output of stderr (if available):</summary>

```
<<< REPLACE THIS LINE WITH ACTUAL OUTPUT >>> 
```
</details>


**Logfile**
Please also *attach* the TexText log file. You find it at the following locations:
  - Windows: `C:\Users\[Your user name]\AppData\Roaming\textext`
  - Linux: `~/.cache/textext`
  - Mac: `~/Library/Preferences/textext`

**Screenshots**
If applicable and helpful, add screenshots to help explain your problem.

**System information**

- TexText version:
- Inkscape version:
- Operating system: [e.g. Windows 10, 1803, 32-bit]
- Windows only: LaTeX-distribution (MiKTeX, TeX-Live):
- Windows only: TexText installed via batch script or installer file:
